@@ -10,8 +10,12 @@
 ( cd opt/kde/share/doc/HTML/pt/juk ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
 ( cd opt/kde/share/doc/HTML/pt/kpf ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/pt/kpf ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
+( cd opt/kde/share/doc/HTML/pt/ktuberling ; rm -rf common )
+( cd opt/kde/share/doc/HTML/pt/ktuberling ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
 ( cd opt/kde/share/doc/HTML/pt/amor ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/pt/amor ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
+( cd opt/kde/share/doc/HTML/pt/karm ; rm -rf common )
+( cd opt/kde/share/doc/HTML/pt/karm ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
 ( cd opt/kde/share/doc/HTML/pt/kate ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/pt/kate ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
 ( cd opt/kde/share/doc/HTML/pt/kdat ; rm -rf common )
@@ -36,10 +40,14 @@
 ( cd opt/kde/share/doc/HTML/pt/kpat ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
 ( cd opt/kde/share/doc/HTML/pt/kpdf ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/pt/kpdf ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
+( cd opt/kde/share/doc/HTML/pt/korn ; rm -rf common )
+( cd opt/kde/share/doc/HTML/pt/korn ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
 ( cd opt/kde/share/doc/HTML/pt/kppp ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/pt/kppp ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
 ( cd opt/kde/share/doc/HTML/pt/krdc ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/pt/krdc ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
+( cd opt/kde/share/doc/HTML/pt/krec ; rm -rf common )
+( cd opt/kde/share/doc/HTML/pt/krec ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
 ( cd opt/kde/share/doc/HTML/pt/krfb ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/pt/krfb ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
 ( cd opt/kde/share/doc/HTML/pt/kscd ; rm -rf common )
@@ -58,6 +66,12 @@
 ( cd opt/kde/share/doc/HTML/pt/ksysguard ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
 ( cd opt/kde/share/doc/HTML/pt/kbounce ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/pt/kbounce ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
+( cd opt/kde/share/doc/HTML/pt/kdearch ; rm -rf common )
+( cd opt/kde/share/doc/HTML/pt/kdearch ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
+( cd opt/kde/share/doc/HTML/pt/kdelirc/kcmlirc ; rm -rf common )
+( cd opt/kde/share/doc/HTML/pt/kdelirc/kcmlirc ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
+( cd opt/kde/share/doc/HTML/pt/kdelirc/irkick ; rm -rf common )
+( cd opt/kde/share/doc/HTML/pt/kdelirc/irkick ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
 ( cd opt/kde/share/doc/HTML/pt/kbattleship ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/pt/kbattleship ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
 ( cd opt/kde/share/doc/HTML/pt/kaboodle ; rm -rf common )
@@ -74,6 +88,8 @@
 ( cd opt/kde/share/doc/HTML/pt/khexedit ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
 ( cd opt/kde/share/doc/HTML/pt/kpercentage ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/pt/kpercentage ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
+( cd opt/kde/share/doc/HTML/pt/kandy ; rm -rf common )
+( cd opt/kde/share/doc/HTML/pt/kandy ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
 ( cd opt/kde/share/doc/HTML/pt/kcalc ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/pt/kcalc ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
 ( cd opt/kde/share/doc/HTML/pt/kdesu ; rm -rf common )
@@ -90,14 +106,20 @@
 ( cd opt/kde/share/doc/HTML/pt/kiten ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
 ( cd opt/kde/share/doc/HTML/pt/kjots ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/pt/kjots ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
+( cd opt/kde/share/doc/HTML/pt/kmail ; rm -rf common )
+( cd opt/kde/share/doc/HTML/pt/kmail ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
 ( cd opt/kde/share/doc/HTML/pt/kmoon ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/pt/kmoon ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
+( cd opt/kde/share/doc/HTML/pt/knode ; rm -rf common )
+( cd opt/kde/share/doc/HTML/pt/knode ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
 ( cd opt/kde/share/doc/HTML/pt/kooka ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/pt/kooka ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
 ( cd opt/kde/share/doc/HTML/pt/ksame ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/pt/ksame ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
 ( cd opt/kde/share/doc/HTML/pt/ksirc ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/pt/ksirc ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
+( cd opt/kde/share/doc/HTML/pt/ktnef ; rm -rf common )
+( cd opt/kde/share/doc/HTML/pt/ktnef ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
 ( cd opt/kde/share/doc/HTML/pt/ksysv ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/pt/ksysv ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
 ( cd opt/kde/share/doc/HTML/pt/ktron ; rm -rf common )
@@ -122,10 +144,16 @@
 ( cd opt/kde/share/doc/HTML/pt/kmousetool ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
 ( cd opt/kde/share/doc/HTML/pt/ksnapshot ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/pt/ksnapshot ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
+( cd opt/kde/share/doc/HTML/pt/klinkstatus ; rm -rf common )
+( cd opt/kde/share/doc/HTML/pt/klinkstatus ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
 ( cd opt/kde/share/doc/HTML/pt/kompare ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/pt/kompare ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
+( cd opt/kde/share/doc/HTML/pt/kontact ; rm -rf common )
+( cd opt/kde/share/doc/HTML/pt/kontact ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
 ( cd opt/kde/share/doc/HTML/pt/konsole ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/pt/konsole ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
+( cd opt/kde/share/doc/HTML/pt/konsolekalendar ; rm -rf common )
+( cd opt/kde/share/doc/HTML/pt/konsolekalendar ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
 ( cd opt/kde/share/doc/HTML/pt/kcachegrind ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/pt/kcachegrind ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
 ( cd opt/kde/share/doc/HTML/pt/kpackage ; rm -rf common )
@@ -140,6 +168,8 @@
 ( cd opt/kde/share/doc/HTML/pt/konquest ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
 ( cd opt/kde/share/doc/HTML/pt/kspaceduel ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/pt/kspaceduel ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
+( cd opt/kde/share/doc/HTML/pt/kturtle ; rm -rf common )
+( cd opt/kde/share/doc/HTML/pt/kturtle ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
 ( cd opt/kde/share/doc/HTML/pt/kverbos ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/pt/kverbos ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
 ( cd opt/kde/share/doc/HTML/pt/kwallet ; rm -rf common )
@@ -158,8 +188,6 @@
 ( cd opt/kde/share/doc/HTML/pt/kmenuedit ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
 ( cd opt/kde/share/doc/HTML/pt/kioslave ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/pt/kioslave ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
-( cd opt/kde/share/doc/HTML/pt/flashkard ; rm -rf common )
-( cd opt/kde/share/doc/HTML/pt/flashkard ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
 ( cd opt/kde/share/doc/HTML/pt/kbackgammon ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/pt/kbackgammon ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
 ( cd opt/kde/share/doc/HTML/pt/kaddressbook ; rm -rf common )
@@ -376,6 +404,8 @@
 ( cd opt/kde/share/doc/HTML/pt/konq-plugins ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
 ( cd opt/kde/share/doc/HTML/pt/kbabel ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/pt/kbabel ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
+( cd opt/kde/share/doc/HTML/pt/kalarm ; rm -rf common )
+( cd opt/kde/share/doc/HTML/pt/kalarm ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
 ( cd opt/kde/share/doc/HTML/pt/kamera ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/pt/kamera ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
 ( cd opt/kde/share/doc/HTML/pt/kdeprint ; rm -rf common )
@@ -390,8 +420,12 @@
 ( cd opt/kde/share/doc/HTML/pt/kgamma ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
 ( cd opt/kde/share/doc/HTML/pt/kmessedwords ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/pt/kmessedwords ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
+( cd opt/kde/share/doc/HTML/pt/kdevelop ; rm -rf common )
+( cd opt/kde/share/doc/HTML/pt/kdevelop ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
 ( cd opt/kde/share/doc/HTML/pt/kicker ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/pt/kicker ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
+( cd opt/kde/share/doc/HTML/pt/klatin ; rm -rf common )
+( cd opt/kde/share/doc/HTML/pt/klatin ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
 ( cd opt/kde/share/doc/HTML/pt/klines ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/pt/klines ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
 ( cd opt/kde/share/doc/HTML/pt/kmines ; rm -rf common )
@@ -400,12 +434,14 @@
 ( cd opt/kde/share/doc/HTML/pt/kmouth ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
 ( cd opt/kde/share/doc/HTML/pt/kmplot ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/pt/kmplot ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
+( cd opt/kde/share/doc/HTML/pt/knotes ; rm -rf common )
+( cd opt/kde/share/doc/HTML/pt/knotes ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
 ( cd opt/kde/share/doc/HTML/pt/kpager ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/pt/kpager ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
-( cd opt/kde/share/doc/HTML/pt/kpaint ; rm -rf common )
-( cd opt/kde/share/doc/HTML/pt/kpaint ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
 ( cd opt/kde/share/doc/HTML/pt/kopete ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/pt/kopete ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
+( cd opt/kde/share/doc/HTML/pt/kpilot ; rm -rf common )
+( cd opt/kde/share/doc/HTML/pt/kpilot ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
 ( cd opt/kde/share/doc/HTML/pt/kpoker ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/pt/kpoker ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
 ( cd opt/kde/share/doc/HTML/pt/kruler ; rm -rf common )
@@ -440,6 +476,12 @@
 ( cd opt/kde/share/doc/HTML/pt/quanta ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
 ( cd opt/kde/share/doc/HTML/pt/kuickshow ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/pt/kuickshow ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
+( cd opt/kde/share/doc/HTML/pt/kolourpaint ; rm -rf common )
+( cd opt/kde/share/doc/HTML/pt/kolourpaint ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
+( cd opt/kde/share/doc/HTML/pt/kde_app_devel ; rm -rf common )
+( cd opt/kde/share/doc/HTML/pt/kde_app_devel ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
+( cd opt/kde/share/doc/HTML/pt/kommander ; rm -rf common )
+( cd opt/kde/share/doc/HTML/pt/kommander ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
 ( cd opt/kde/share/doc/HTML/pt/kiconedit ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/pt/kiconedit ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
 ( cd opt/kde/share/doc/HTML/pt/klettres ; rm -rf common )
@@ -452,10 +494,14 @@
 ( cd opt/kde/share/doc/HTML/pt/klickety ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
 ( cd opt/kde/share/doc/HTML/pt/kpovmodeler ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/pt/kpovmodeler ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
+( cd opt/kde/share/doc/HTML/pt/kleopatra ; rm -rf common )
+( cd opt/kde/share/doc/HTML/pt/kleopatra ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
 ( cd opt/kde/share/doc/HTML/pt/kjumpingcube ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/pt/kjumpingcube ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
 ( cd opt/kde/share/doc/HTML/pt/kenolaba ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/pt/kenolaba ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
+( cd opt/kde/share/doc/HTML/pt/kwatchgnupg ; rm -rf common )
+( cd opt/kde/share/doc/HTML/pt/kwatchgnupg ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
 ( cd opt/kde/share/doc/HTML/pt/kworldclock ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/pt/kworldclock ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
 ( cd opt/kde/share/doc/HTML/pt/KRegExpEditor ; rm -rf common )
@@ -508,5 +554,9 @@
 ( cd opt/kde/share/doc/HTML/pt/umbrello ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
 ( cd opt/kde/share/doc/HTML/pt/konqueror ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/pt/konqueror ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
+( cd opt/kde/share/doc/HTML/pt/kwordquiz ; rm -rf common )
+( cd opt/kde/share/doc/HTML/pt/kwordquiz ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
+( cd opt/kde/share/doc/HTML/pt/korganizer ; rm -rf common )
+( cd opt/kde/share/doc/HTML/pt/korganizer ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
 ( cd opt/kde/share/doc/HTML/pt/atlantik ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/pt/atlantik ; ln -sf /opt/kde/share/doc/HTML/pt/common common )
